@@ -1,7 +1,7 @@
 /* GENIUS Calculator
- * Copyright (C) 1997-2002 George Lebl
+ * Copyright (C) 1997-2004 Jiri (George) Lebl
  *
- * Author: George Lebl
+ * Author: Jiri (George) Lebl
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -139,6 +139,8 @@ void mpw_set_default_prec(unsigned long int i);
 /*initialize a number*/
 void mpw_init(mpw_ptr op);
 void mpw_init_set(mpw_ptr rop,mpw_ptr op);
+/* don't try to decomplexify the number */
+void mpw_init_set_no_uncomplex (mpw_ptr rop, mpw_ptr op);
 
 /*clear memory held by number*/
 void mpw_clear(mpw_ptr op);
@@ -148,6 +150,7 @@ void mpw_make_same_type(mpw_ptr op1,mpw_ptr op2);
 
 void mpw_set(mpw_ptr rop,mpw_ptr op);
 void mpw_set_d(mpw_ptr rop,double d);
+void mpw_set_d_complex (mpw_ptr rop, double real, double imag);
 void mpw_set_si(mpw_ptr rop,signed long int i);
 void mpw_set_ui(mpw_ptr rop,unsigned long int i);
 void mpw_set_mpz_use (mpw_ptr rop, mpz_ptr op);
@@ -235,8 +238,8 @@ void mpw_conj (mpw_ptr rop, mpw_ptr op);
 int mpw_cmp(mpw_ptr op1, mpw_ptr op2);
 int mpw_cmp_ui(mpw_ptr op, unsigned long int i);
 
-int mpw_eql(mpw_ptr op1, mpw_ptr op2);
-int mpw_eql_ui(mpw_ptr op, unsigned long int i);
+gboolean mpw_eql(mpw_ptr op1, mpw_ptr op2);
+gboolean mpw_eql_ui(mpw_ptr op, unsigned long int i);
 
 void mpw_fac_ui(mpw_ptr rop,unsigned long int i);
 void mpw_fac(mpw_ptr rop,mpw_ptr op);
